
==============
Pooling Layers
==============


.. automodule:: npdl.layers.pooling

.. currentmodule:: npdl.layers


.. autoclass:: MeanPooling
   :members:


.. autoclass:: MaxPooling
   :members:



